Combines power of torch, numerical methods and math overall to conquer and solve ALL {O,P}DEs

There are three examples to provide a little insight to an operator form

- example_wave.py - Wave equation
- example_KdV.py - Korteweg- de Vries equation
- example_ODE.py - Legendre polynomial generator equation
- example_schrodinger.py - Schrodinger equation
